#! /bin/bash
#restore a Pupsave backup or switch to Pupsave backup
#250126 rev3
#author - wizard on the Puppy Linux forum

yad --title "Backup or Restore Ver3" \
--button="Pupsave Backup":1 \
--button="Pupsave Restore":0 \
--button=Cancel:2 \
--text "
Choose if you want to Backup or Restore your Puppy

"
#do choice
ret=$?
if [ $ret == 2 ]; then
     exit
   elif [ $ret == 1 ]; then
     pupsave-backup
     exit
fi

yad --title "Restore Pupsave Backup" \
    --width=400 \
    --text "This program can restore:
-compressed or un-compressed savefile backup
-compressed savefolder backup

Your backup files must be in the same
directory as your main Puppy install

Be certain you have enough space on your boot 
drive partition to hold the restore.

When you reboot you will see a personal file 
choice menu that list your backups." \
--button=OK:1 \
--button=Cancel:0 \

#exit if cancel
ret=$?
if [ $ret == 0 ]; then
    exit
fi

#get install directory
source /etc/rc.d/PUPSTATE
pupdir="/mnt/home$PSUBDIR"
#echo  "$pupdir"
cd $pupdir

#create list of .BKP backups
rm backups.txt
ls *.BKP* > $pupdir/backups.txt

#list backups to select
yad --title "Restore Backup, select & wait for complete message" \
    --width=550 \
    --height=150 \
    --center \
    --button=OK:1 \
    --button=Cancel:0 \
    --list \
    --select-action="echo">restorefile.txt \
    --column="Backups" < $pupdir/backups.txt 
#exit if cancel
ret=$?
if [ $ret == 0 ]; then
    exit
fi    

#set restore file selected    
restorefile=$(cat restorefile.txt)
rm restorefile.txt
#echo $restorefile

#user add to restore name
add=( $(yad --form --title="Add To Name" \
--text="You can add to the restore file or folder name 
Keep it short and don't use spaces" \
--separator=' '  \
--button="OK":2 \
--button="Skip":0 \
--field="Add to name" \ ))

ret=$?

addname=-$add

if [ $ret == 0 ]; then
    addname=""
fi
echo $addname

#Code for un-compressed
#get file system type 
if [[ "$restorefile" == *"2fs"* ]]; then
    ftype=.2fs
  elif [[ "$restorefile" == *"3fs"* ]]; then
    ftype=.3fs
  elif [[ "$restorefile" == *"4fs"* ]]; then
    ftype=.4fs
  else
     ftype=none
fi
#echo $ftype

if [[ ! $restorefile == *".tar"* ]];then
    #echo Backup is a savefile not compressed
    #get distro file namme
    fname=`echo "$restorefile" | cut -d'.' -f1`
       
   #copy file to new name
   bkpname=$fname-RESTORED$addname$ftype
   #echo $bkname
   cp $restorefile $pupdir/$bkpname 
   yad --title "Restore Complete" \
    --width=250 \
    --height=150 \
    --center \
    --button=OK \
    --text "Restore is named:
$bkpname

You must reboot to use" 
      exit  
 fi 
#End code for un-compressed

#wait msg
yad --title "Wait" \
    --button=OK \
    --text "Wait for the completed message" \ &

#extract compressed file to extracted dir
rm -r extracted
mkdir extracted
tar -xf $restorefile -C extracted

#move renamed backup to install dir
cd extracted
extractedbkp=$(ls)
 
#test if extract is file or dir
if [ -d "$pupdir/extracted/"$extractedbkp"" ]; then
  #echo "directory"
  #echo $extractedbkp
  mv $extractedbkp $pupdir/"$extractedbkp"-RESTORED$addname
  
  yad --title "Restore Complete" \
    --width=250 \
    --height=150 \
    --center \
    --button=OK \
    --text "Restore is named:
"$extractedbkp"-RESTORED$addname

You must reboot to use" \

#delete temporary files/dir
     rm -r $pupdir/extracted
     rm $pupdir/backups.txt
     exit
  else
  echo "Backup is a savefile"
fi

#Backup is a savefile
#get distro file namme
fname=`echo "$extractedbkp" | cut -d'.' -f1`

#get file system type
if [[ "$extractedbkp" == *"2fs"* ]]; then
    ftype=.2fs
  elif [[ "$extractedbkp" == *"3fs"* ]]; then
    ftype=.3fs
  elif [[ "$extractedbkp" == *"4fs"* ]]; then
    ftype=.4fs
  else
    yad  --title "Restore Fail" \
     --button=OK \
     --text "File is not a Linux file system,
Exiting" 
    #delete temporary files/dir
   rm -r $pupdir/extracted
   rm $pupdir/restorefile.txt
   rm $pupdir/backups.txt    
   exit  #quit if file is not a xfs
fi

#move restored file
bkpname=$fname-RESTORED$addname$ftype
mv $extractedbkp $pupdir/$bkpname 

yad --title "Restore Complete" \
    --width=250 \
    --height=150 \
    --center \
    --button=OK \
    --text "Restore is named:
"$bkpname"

You must reboot to use" \

#delete temporary files/dir
rm -r $pupdir/extracted
rm $pupdir/backups.txt

exit















